{% extends "wagtailadmin/widgets/chooser.html" %}
{% load i18n %}


{% block chosen_icon %}
    {# Empty alt because the chosen item’s title is already displayed next to the image. #}
    <img
        class="chooser__image"
        data-chooser-image
        alt=""
        class="show-transparency"
        height="{{ preview.height }}"
        width="{{ preview.width }}"
        src="{{ preview.url }}"
    />
{% endblock chosen_icon %}
