# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-08 06:48
from __future__ import absolute_import, print_function, unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailvideos', '0006_auto_20160707_1413'),
    ]

    operations = [
        migrations.AddField(
            model_name='video',
            name='duration',
            field=models.CharField(blank=True, max_length=255),
        ),
    ]
