# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-06 01:53
from __future__ import absolute_import, print_function, unicode_literals

from django.db import migrations, models

import wagtailvideos.models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailvideos', '0003_auto_20160705_1646'),
    ]

    operations = [
        migrations.AlterField(
            model_name='videotranscode',
            name='file',
            field=models.FileField(blank=True, null=True, upload_to=wagtailvideos.models.get_upload_to, verbose_name='file'),
        ),
    ]
