# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-07 04:13
from __future__ import absolute_import, print_function, unicode_literals

from django.db import migrations, models

import wagtailvideos.models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailvideos', '0005_videotranscode_error_message'),
    ]

    operations = [
        migrations.AlterField(
            model_name='video',
            name='thumbnail',
            field=models.ImageField(blank=True, null=True, upload_to=wagtailvideos.models.get_upload_to),
        ),
    ]
