# Generated by Django 2.0.7 on 2018-10-09 23:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailvideos', '0009_videotranscode_quality'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='video',
            options={'ordering': ['-created_at']},
        ),
    ]
