# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-05 06:46
from __future__ import absolute_import, print_function, unicode_literals

import django.db.models.deletion
import enumchoicefield.fields
from django.db import migrations, models

import wagtailvideos.models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailvideos', '0002_auto_20160321_1610'),
    ]

    operations = [
        migrations.CreateModel(
            name='VideoTranscode',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('media_format', enumchoicefield.fields.EnumChoiceField(enum_class=wagtailvideos.models.MediaFormats, max_length=4)),
                ('processing', models.BooleanField(default=False)),
                ('file', models.FileField(null=True, upload_to=wagtailvideos.models.get_upload_to, verbose_name='file')),
                ('video', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transcodes', to='wagtailvideos.Video')),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='videotranscode',
            unique_together=set([('video', 'media_format')]),
        ),
    ]
