# Generated by Django 4.2.3 on 2023-07-18 23:19

from django.db import migrations
import wagtail.fields
import wagtailvideos.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='testpage',
            name='video_streamfield',
            field=wagtail.fields.StreamField([('video', wagtailvideos.blocks.VideoChooserBlock())], blank=True, use_json_field=True),
        ),
    ]
