{% extends "wagtailadmin/permissions/includes/collection_member_permissions_formset.html" %}
{% load i18n %}

{% block title %}{% trans "Video permissions" %}{% endblock %}
{% block add_button_label %}{% trans "Add an video permission" %}{% endblock %}
